@@ -1,6 +1,5 @@
 package MyRole2;
-use Evo;
-use Evo::Role '*';
+use Evo '-Role *';
 
 requires qw(rmethod a1 m1);
 has 'a2' => 'a2val';
